# Hologram

Hologram is a lightweight library to generate Draft 7 compatible JSON Schemas from python 3.7 dataclasses. Python 3.6 is supported through the [dataclasses backport](https://github.com/ericvsmith/dataclasses). It is forked from [dataclasses-jsonschema](https://github.com/s-knibbs/dataclasses-jsonschema) created by [s-knibbs](https://github.com/s-knibbs).
